==> po.simple_test-0.4.1.tar.gz: po.simple_test-0.4.1/setup.py <==
# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['po',
 'po.simple_test',
 'po.simple_test._vendor',
 'po.simple_test._vendor.case_conversion',
 'po.simple_test._vendor.simple_test_process',
 'po.simple_test._vendor.simple_test_process._vendor',
 'po.simple_test._vendor.simple_test_process._vendor.case_conversion',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.simple_chalk',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.simple_chalk.src',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.simple_chalk.src.utils',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.simple_chalk.src.utils.internal',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.simple_chalk.tests',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.tedent',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.tedent._vendor',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.tedent._vendor.wrapt',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.tedent.fns',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.tedent.fns.decorators',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.tedent.fns.internal',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.wrapt',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter.fns',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter.fns.decorators',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter.fns.internal',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter.report',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter.report.initRootState',
 'po.simple_test._vendor.simple_test_process._vendor.tedent',
 'po.simple_test._vendor.simple_test_process._vendor.tedent._vendor',
 'po.simple_test._vendor.simple_test_process._vendor.tedent._vendor.wrapt',
 'po.simple_test._vendor.simple_test_process._vendor.tedent.fns',
 'po.simple_test._vendor.simple_test_process._vendor.tedent.fns.decorators',
 'po.simple_test._vendor.simple_test_process._vendor.tedent.fns.internal',
 'po.simple_test._vendor.simple_test_process._vendor.toml',
 'po.simple_test._vendor.simple_test_process._vendor.wrapt',
 'po.simple_test._vendor.simple_test_process.fns',
 'po.simple_test._vendor.simple_test_process.fns.decorators',
 'po.simple_test._vendor.simple_test_process.fns.internal',
 'po.simple_test._vendor.tedent',
 'po.simple_test._vendor.tedent._vendor',
 'po.simple_test._vendor.tedent._vendor.wrapt',
 'po.simple_test._vendor.tedent.fns',
 'po.simple_test._vendor.tedent.fns.decorators',
 'po.simple_test._vendor.tedent.fns.internal',
 'po.simple_test._vendor.wrapt',
 'po.simple_test.cli',
 'po.simple_test.fns',
 'po.simple_test.fns.decorators',
 'po.simple_test.fns.internal',
 'po.simple_test.run']

package_data = \
{'': ['*'],
 'po.simple_test._vendor': ['case_conversion-2.1.0.dist-info/*',
                            'ordered_set-3.1.1.dist-info/*',
                            'simple_test_process-0.4.4.dist-info/*',
                            'tedent-0.1.5.dist-info/*',
                            'wrapt-1.10.11.dist-info/*'],
 'po.simple_test._vendor.simple_test_process._vendor': ['bin/*',
                                                        'case_conversion-2.1.0.dist-info/*',
                                                        'ordered_set-3.1.1.dist-info/*',
                                                        'simple_test_default_reporter-0.2.1.dist-info/*',
                                                        'tedent-0.1.5.dist-info/*',
                                                        'toml-0.10.0.dist-info/*',
                                                        'wrapt-1.10.11.dist-info/*'],
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor': ['ordered_set-3.1.1.dist-info/*',
                                                                                             'simple_chalk-0.1.0.dist-info/*',
                                                                                             'tedent-0.1.5.dist-info/*',
                                                                                             'wrapt-1.10.11.dist-info/*'],
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.tedent._vendor': ['ordered_set-3.1.1-py3.7.egg-info/*',
                                                                                                            'wrapt-1.11.1.dist-info/*'],
 'po.simple_test._vendor.simple_test_process._vendor.tedent._vendor': ['ordered_set-3.1.1-py3.7.egg-info/*',
                                                                       'wrapt-1.11.1.dist-info/*'],
 'po.simple_test._vendor.tedent._vendor': ['ordered_set-3.1.1-py3.7.egg-info/*',
                                           'wrapt-1.11.1.dist-info/*']}

entry_points = \
{'console_scripts': ['simple-test = po.simple_test.script:main']}

setup_kwargs = {
    'name': 'po.simple-test',
    'version': '0.4.1',
    'description': 'A simple test runner',
    'long_description': 'I will document this module if people will find it helpful.  Currently\nsimple_test is just for my own personal use.\n',
    'author': 'Philip Olson',
    'author_email': 'philip.olson@pm.me',
    'url': 'https://github.com/olsonpm/py_simple-test',
    'packages': packages,
    'package_data': package_data,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)

==> po.simple_test-0.4.2.tar.gz: po.simple_test-0.4.2/setup.py <==
# -*- coding: utf-8 -*-
from distutils.core import setup

packages = \
['po',
 'po.simple_test',
 'po.simple_test._vendor',
 'po.simple_test._vendor.po',
 'po.simple_test._vendor.po.case_conversion',
 'po.simple_test._vendor.simple_test_process',
 'po.simple_test._vendor.simple_test_process._vendor',
 'po.simple_test._vendor.simple_test_process._vendor.po',
 'po.simple_test._vendor.simple_test_process._vendor.po.case_conversion',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.simple_chalk',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.simple_chalk.src',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.simple_chalk.src.utils',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.simple_chalk.src.utils.internal',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.simple_chalk.tests',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.tedent',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.tedent._vendor',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.tedent._vendor.wrapt',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.tedent.fns',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.tedent.fns.decorators',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.tedent.fns.internal',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.wrapt',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter.fns',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter.fns.decorators',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter.fns.internal',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter.report',
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter.report.initRootState',
 'po.simple_test._vendor.simple_test_process._vendor.tedent',
 'po.simple_test._vendor.simple_test_process._vendor.tedent._vendor',
 'po.simple_test._vendor.simple_test_process._vendor.tedent._vendor.wrapt',
 'po.simple_test._vendor.simple_test_process._vendor.tedent.fns',
 'po.simple_test._vendor.simple_test_process._vendor.tedent.fns.decorators',
 'po.simple_test._vendor.simple_test_process._vendor.tedent.fns.internal',
 'po.simple_test._vendor.simple_test_process._vendor.toml',
 'po.simple_test._vendor.simple_test_process._vendor.wrapt',
 'po.simple_test._vendor.simple_test_process.fns',
 'po.simple_test._vendor.simple_test_process.fns.decorators',
 'po.simple_test._vendor.simple_test_process.fns.internal',
 'po.simple_test._vendor.tedent',
 'po.simple_test._vendor.tedent._vendor',
 'po.simple_test._vendor.tedent._vendor.wrapt',
 'po.simple_test._vendor.tedent.fns',
 'po.simple_test._vendor.tedent.fns.decorators',
 'po.simple_test._vendor.tedent.fns.internal',
 'po.simple_test._vendor.wrapt',
 'po.simple_test.cli',
 'po.simple_test.fns',
 'po.simple_test.fns.decorators',
 'po.simple_test.fns.internal',
 'po.simple_test.run']

package_data = \
{'': ['*'],
 'po.simple_test._vendor': ['ordered_set-3.1.1.dist-info/*',
                            'po.case_conversion-0.3.0.dist-info/*',
                            'simple_test_process-0.5.0.dist-info/*',
                            'tedent-0.1.5.dist-info/*',
                            'wrapt-1.10.11.dist-info/*'],
 'po.simple_test._vendor.simple_test_process._vendor': ['ordered_set-3.1.1.dist-info/*',
                                                        'po.case_conversion-0.2.0.dist-info/*',
                                                        'simple_test_default_reporter-0.2.1.dist-info/*',
                                                        'tedent-0.1.5.dist-info/*',
                                                        'toml-0.10.0.dist-info/*',
                                                        'wrapt-1.10.11.dist-info/*'],
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor': ['ordered_set-3.1.1.dist-info/*',
                                                                                             'simple_chalk-0.1.0.dist-info/*',
                                                                                             'tedent-0.1.5.dist-info/*',
                                                                                             'wrapt-1.10.11.dist-info/*'],
 'po.simple_test._vendor.simple_test_process._vendor.simple_test_default_reporter._vendor.tedent._vendor': ['ordered_set-3.1.1-py3.7.egg-info/*',
                                                                                                            'wrapt-1.11.1.dist-info/*'],
 'po.simple_test._vendor.simple_test_process._vendor.tedent._vendor': ['ordered_set-3.1.1-py3.7.egg-info/*',
                                                                       'wrapt-1.11.1.dist-info/*'],
 'po.simple_test._vendor.tedent._vendor': ['ordered_set-3.1.1-py3.7.egg-info/*',
                                           'wrapt-1.11.1.dist-info/*']}

entry_points = \
{'console_scripts': ['simple-test = po.simple_test.script:main']}

setup_kwargs = {
    'name': 'po.simple-test',
    'version': '0.4.2',
    'description': 'A simple test runner',
    'long_description': 'I will document this module if people will find it helpful.  Currently\nsimple_test is just for my own personal use.\n',
    'author': 'Philip Olson',
    'author_email': 'philip.olson@pm.me',
    'url': 'https://github.com/olsonpm/py_simple-test',
    'packages': packages,
    'package_data': package_data,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
